emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] elpa-admin 7e321ea68a: * elpa-admin.el: Use `.txt` i.s.o `.log` s


From: Stefan Monnier
Subject: [elpa] elpa-admin 7e321ea68a: * elpa-admin.el: Use `.txt` i.s.o `.log` so web server gives right mime-type
Date: Wed, 23 Nov 2022 14:42:33 -0500 (EST)

branch: elpa-admin
commit 7e321ea68aee8f3aea1521d925340b053f21d0df
Author: Stefan Monnier <monnier@iro.umontreal.ca>
Commit: Stefan Monnier <monnier@iro.umontreal.ca>

    * elpa-admin.el: Use `.txt` i.s.o `.log` so web server gives right mime-type
---
 elpa-admin.el | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/elpa-admin.el b/elpa-admin.el
index 88b1f17d70..81b827b004 100644
--- a/elpa-admin.el
+++ b/elpa-admin.el
@@ -677,7 +677,7 @@ auxiliary files unless TARBALL-ONLY is non-nil ."
                    "######## Build of package %s FAILED!!")
                  tarball)
         (let* ((pkg-name (car pkg-spec))
-               (logfile (expand-file-name (format "%s-build-failure.log"
+               (logfile (expand-file-name (format "%s-build-failure.txt"
                                                   pkg-name)
                                           (file-name-directory tarball))))
           (if res
@@ -708,7 +708,7 @@ auxiliary files unless TARBALL-ONLY is non-nil ."
                       "The build scripts failed to build the tarball
 for version %s of the package %s.
 You can consult the latest error output in the file
-\"%s-build-failure.log\" in the corresponding ELPA archive web site.
+\"%s-build-failure.txt\" in the corresponding ELPA archive web site.
 
 The current error output was the following:\n\n%s"
                       (if (consp metadata-or-version)
@@ -2552,7 +2552,7 @@ relative to elpa root."
 (defun elpaa--record-sync-failure (pkg-spec msg)
   (when (file-directory-p elpaa--sync-failures-dir)
     (let* ((pkg (car pkg-spec))
-           (logfile (expand-file-name (format "%s-sync-failure.log" pkg)
+           (logfile (expand-file-name (format "%s-sync-failure.txt" pkg)
                                       elpaa--sync-failures-dir)))
       (if (null msg)
           (delete-file logfile)
@@ -2578,7 +2578,7 @@ relative to elpa root."
 ;;             "The build scripts failed to build the tarball
 ;; for version %s of the package %s.
 ;; You can consult the latest error output in the file
 ;; \"%s-build-failure.log\" in the corresponding ELPA archive web site.
 
 ;; The current error output was the following:\n\n%s"
 ;;             (or (car-safe metadata-or-version) metadata-or-version)
@@ -2578,7 +2578,7 @@ relative to elpa root."
 ;; for version %s of the package %s.
 ;; You can consult the latest error output in the file
-;; \"%s-build-failure.log\" in the corresponding ELPA archive web site.
+;; \"%s-sync-failure.txt\" in the corresponding ELPA archive web site.
 
 ;; The current error output was the following:\n\n%s"



reply via email to

[Prev in Thread] Current Thread [Next in Thread]